==> pangea-center-api-0.0.8-mhs2-20191106.084307-6-sources.jar: cn/com/duiba/tuia/pangea/center/api/req/PlanInsertReq.java <==
package cn.com.duiba.tuia.pangea.center.api.req;

import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.List;

/**
 * @author fenglijun
 * @version 1.0
 * @since 2019-09-02 14:41
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class PlanInsertReq implements Serializable {

    private static final long serialVersionUID = 1338140691908924164L;
    @ApiModelProperty(value = "测试计划名称", required = true, dataType = "string")
    @NotBlank(message = "测试计划名称不能为空")
    private String planName;

    @ApiModelProperty(value = "对照组活动id", required = true)
    private String controlGroup;

    @ApiModelProperty(value = "对照组活动占比", required = true)
    private Integer controlPercent;

    @ApiModelProperty(value = "测试计划开始时间", required = true)
    private String startTime;

    @ApiModelProperty(value = "测试计划结束时间", required = true)
    private String endTime;

    @ApiModelProperty(value = "流量选择类型", required = true)
    private Integer flowType;

    @ApiModelProperty(value = "测试人", required = true)
    private String testName;

    @ApiModelProperty(value = "测试人adminId")
    private Long adminId;

    @ApiModelProperty(value = "广告位集合", required = false)
    private List<Long> slotIds;

    @ApiModelProperty(value = "对照组和活动组信息", required = false)
    private List<SlotIdToContrastReq> planSlots;

    @ApiModelProperty(value = "用户行为缓存", required = false)
    private String userActionCache;

    @ApiModelProperty(value = "测试范围是否是全部有回流数据活动，1：是，0：否，使用输入的活动列表")
    private Integer testActivityAll;

    @ApiModelProperty(value = "测试活动ID列表")
    private List<Long> activityIds;

    @ApiModelProperty(value = "测试类型，默认0：活动ABTest，1：浮标，2：下拉，3：返回拦截，11：响应式插件，21：弹层", required = true)
    private Integer testType;
}

==> pangea-center-api-0.0.15-mhs-20191216.070639-3-sources.jar: cn/com/duiba/tuia/pangea/center/api/req/PlanInsertReq.java <==
package cn.com.duiba.tuia.pangea.center.api.req;

import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;
import java.util.List;

/**
 * @author fenglijun
 * @version 1.0
 * @since 2019-09-02 14:41
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class PlanInsertReq implements Serializable {

    private static final long serialVersionUID = 1338140691908924164L;
    @ApiModelProperty(value = "测试计划名称", required = true, dataType = "string")
    @NotBlank(message = "测试计划名称不能为空")
    private String planName;

    @ApiModelProperty(value = "对照组活动id", required = true)
    private String controlGroup;

    @ApiModelProperty(value = "对照组活动占比", required = true)
    private Integer controlPercent;

    @ApiModelProperty(value = "测试计划开始时间", required = true)
    private String startTime;

    @ApiModelProperty(value = "测试计划结束时间", required = true)
    private String endTime;

    @ApiModelProperty(value = "流量选择类型", required = true)
    private Integer flowType;

    @ApiModelProperty(value = "测试人", required = true)
    private String testName;

    @ApiModelProperty(value = "测试人adminId")
    private Long adminId;

    @ApiModelProperty(value = "广告位集合", required = false)
    private List<Long> slotIds;

    @ApiModelProperty(value = "对照组和活动组信息", required = false)
    private List<SlotIdToContrastReq> planSlots;

    @ApiModelProperty(value = "用户行为缓存", required = false)
    private String userActionCache;

    @ApiModelProperty(value = "测试范围是否是全部有回流数据活动，1：是，0：否，使用输入的活动列表")
    private Integer testActivityAll;

    @ApiModelProperty(value = "测试活动ID列表")
    private List<Long> activityIds;

    @ApiModelProperty(value = "测试类型，默认0：活动ABTest，1：浮标，2：下拉，3：返回拦截，11：响应式插件，21：弹层", required = true)
    private Integer testType;

    @ApiModelProperty(value = "测试计划ID，有值表示在编辑")
    private Long planId;

    @ApiModelProperty(value = "当是编辑或追加时广告位已选择的广告位集合", required = false)
    private List<Long> selectSlotIds;
}
